@@ -2,7 +2,7 @@ from veracode_api_py.api import VeracodeAPI
 from veracode_api_py.policy import Policies
 from veracode_api_py.applications import Applications, Sandboxes, CustomFields
 from veracode_api_py.collections import Collections
-from veracode_api_py.dynamic import Analyses, Scans, CodeGroups, Configuration, ScannerVariables, ScanCapacitySummary, Occurrences
+from veracode_api_py.dynamic import Analyses, Scans, CodeGroups, Configuration, ScannerVariables, ScanCapacitySummary, Occurrences, DynUtils
 from veracode_api_py.findings import Findings, SummaryReport
 from veracode_api_py.healthcheck import Healthcheck
 from veracode_api_py.identity import Users, Teams, BusinessUnits, APICredentials, Roles
